# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr
from landing_page_server_connector.models.editor_version_enum import EditorVersionEnum
from landing_page_server_connector.models.portal_language_enum import PortalLanguageEnum

class TemplateListGetPublic(BaseModel):
    """
    TemplateListGetPublic
    """
    id: StrictInt = Field(...)
    language_id: PortalLanguageEnum = Field(...)
    editor_version: EditorVersionEnum = Field(...)
    preview_id: Optional[StrictStr] = None
    name: StrictStr = Field(...)
    title: StrictStr = Field(...)
    path: StrictStr = Field(...)
    order: StrictInt = Field(...)
    __properties = ["id", "language_id", "editor_version", "preview_id", "name", "title", "path", "order"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TemplateListGetPublic:
        """Create an instance of TemplateListGetPublic from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TemplateListGetPublic:
        """Create an instance of TemplateListGetPublic from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TemplateListGetPublic.parse_obj(obj)

        _obj = TemplateListGetPublic.parse_obj({
            "id": obj.get("id"),
            "language_id": obj.get("language_id"),
            "editor_version": obj.get("editor_version"),
            "preview_id": obj.get("preview_id"),
            "name": obj.get("name"),
            "title": obj.get("title"),
            "path": obj.get("path"),
            "order": obj.get("order")
        })
        return _obj


